==> jc-1.4.0.tar.gz: jas/AsciiCP.h <==
// public class jas.AsciiCP

// class file dependencies
// @dep_class 3d17b9781682b756 jas_AsciiCP
// @dep_class c0e5264359137f3 jas_CP
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_CP

#include "jas/CP.h"

#ifndef _JC_jas_AsciiCP_H_
#define _JC_jas_AsciiCP_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jas_AsciiCP$sub_refs	_jc_jas_AsciiCP$sub_refs;
typedef struct _jc_jas_AsciiCP$sub_nonrefs	_jc_jas_AsciiCP$sub_nonrefs;
typedef struct _jc_jas_AsciiCP$refs	_jc_jas_AsciiCP$refs;
typedef struct _jc_jas_AsciiCP$nonrefs	_jc_jas_AsciiCP$nonrefs;
typedef struct _jc_jas_AsciiCP$object	_jc_jas_AsciiCP$object;

typedef const struct _jc_jas_AsciiCP$vmethods	_jc_jas_AsciiCP$vmethods;
typedef const struct _jc_jas_AsciiCP$vtable	_jc_jas_AsciiCP$vtable;
typedef const struct _jc_jas_AsciiCP$vtype	_jc_jas_AsciiCP$vtype;

// Constructors
extern void _jc_jas_AsciiCP$method$_init$c31b894660454d13(_jc_env *, struct _jc_jas_AsciiCP$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_jas_AsciiCP$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_AsciiCP$object *, struct _jc_jas_ClassEnv$object *);
extern struct _jc_java_lang_String$object *_jc_jas_AsciiCP$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_jas_AsciiCP$object *);
extern void _jc_jas_AsciiCP$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_AsciiCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_AsciiCP$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_AsciiCP$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_jas_AsciiCP$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_AsciiCP$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_AsciiCP$object *, struct _jc_jas_ClassEnv$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_jas_AsciiCP$object *);
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_AsciiCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_AsciiCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CP$vmethods	jas_CP;
	_jc_jas_AsciiCP$vmethods	jas_AsciiCP;
};

// Vtype
struct _jc_jas_AsciiCP$vtype {
	_jc_type			type;
	_jc_jas_AsciiCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_AsciiCP$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_AsciiCP$refs {
    _jc_jas_AsciiCP$sub_refs	jas_AsciiCP;
    _jc_jas_CP$sub_refs	jas_CP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_AsciiCP$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_AsciiCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CP$sub_nonrefs	jas_CP;
    _jc_jas_AsciiCP$sub_nonrefs	jas_AsciiCP;
};

// Object instance structure
struct _jc_jas_AsciiCP$object {
	_jc_jas_AsciiCP$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_AsciiCP$vtype	*vtype;
	_jc_jas_AsciiCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_AsciiCP$vtype _jc_jas_AsciiCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_AsciiCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_AsciiCP$class_object;

#endif	/* _JC_jas_AsciiCP_H_ */

==> jc-1.4.6.tar.gz: jas/AsciiCP.h <==
// public class jas.AsciiCP

// class file dependencies
// @dep_class 3d17b9781682b756 jas_AsciiCP
// @dep_class c0e5264359137f3 jas_CP
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_CP

#include "jas/CP.h"

#ifndef _JC_jas_AsciiCP_H_
#define _JC_jas_AsciiCP_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jas_AsciiCP$sub_refs	_jc_jas_AsciiCP$sub_refs;
typedef struct _jc_jas_AsciiCP$sub_nonrefs	_jc_jas_AsciiCP$sub_nonrefs;
typedef struct _jc_jas_AsciiCP$refs	_jc_jas_AsciiCP$refs;
typedef struct _jc_jas_AsciiCP$nonrefs	_jc_jas_AsciiCP$nonrefs;
typedef struct _jc_jas_AsciiCP$object	_jc_jas_AsciiCP$object;

typedef const struct _jc_jas_AsciiCP$vmethods	_jc_jas_AsciiCP$vmethods;
typedef const struct _jc_jas_AsciiCP$vtable	_jc_jas_AsciiCP$vtable;
typedef const struct _jc_jas_AsciiCP$vtype	_jc_jas_AsciiCP$vtype;

// Constructors
extern void _jc_jas_AsciiCP$method$_init$c31b894660454d13(_jc_env *, struct _jc_jas_AsciiCP$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_AsciiCP$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_AsciiCP$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_jas_AsciiCP$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_jas_AsciiCP$object *) _JC_JCNI_ATTR;
extern void _jc_jas_AsciiCP$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_AsciiCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_AsciiCP$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_AsciiCP$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_jas_AsciiCP$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_AsciiCP$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_AsciiCP$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_jas_AsciiCP$object *) _JC_JCNI_ATTR;
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_AsciiCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_AsciiCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CP$vmethods	jas_CP;
	_jc_jas_AsciiCP$vmethods	jas_AsciiCP;
};

// Vtype
struct _jc_jas_AsciiCP$vtype {
	_jc_type			type;
	_jc_jas_AsciiCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_AsciiCP$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_AsciiCP$refs {
    _jc_jas_AsciiCP$sub_refs	jas_AsciiCP;
    _jc_jas_CP$sub_refs	jas_CP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_AsciiCP$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_AsciiCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CP$sub_nonrefs	jas_CP;
    _jc_jas_AsciiCP$sub_nonrefs	jas_AsciiCP;
};

// Object instance structure
struct _jc_jas_AsciiCP$object {
	_jc_jas_AsciiCP$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_AsciiCP$vtype	*vtype;
	_jc_jas_AsciiCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_AsciiCP$vtype _jc_jas_AsciiCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_AsciiCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_AsciiCP$class_object;

#endif	/* _JC_jas_AsciiCP_H_ */
